@@ -421,6 +421,7 @@ void set_signal_mfiler()
 ///////////////////////////////////////////////////
 // メイン関数
 ///////////////////////////////////////////////////
+#if defined(ENABLE_SOCKET)
 static void main_arg_e(char* send_cmd, int pid)
 {
     /// ソケットを送る ///
@@ -474,12 +475,17 @@ static void main_arg_e(char* send_cmd, int pid)
         }
     }
 }
+#endif
 
 static void usage()
 {
+#if defined(ENABLE_SOCKET)
     printf("usage mfiler3 [-e [pid] command] [-E [pid] command] [-c command] [--version ] [ filer initial directory or script file]\n\n");
     printf("-e : send a command to running mfiler3. mfiler3 run the command, and send result to this tty.\n");
     printf("-E : send a command to running mfiler3, mfiler3 run the command, and send result to mfiler3 tty.\n");
+#else
+    printf("usage mfiler3 [-c command] [--version ] [ filer initial directory or script file]\n\n");
+#endif
     printf("-c : eval a command on mfiler3\n");
     printf("--version : display mfiler3 version\n");
 
@@ -878,7 +884,7 @@ int main(int argc, char* argv[])
     CHECKML_BEGIN();
 
     /// ファイラでもスクリプトでも共通の環境変数を初期化 ///
-    setenv("VERSION", "4.0.1", 1);
+    setenv("VERSION", "4.0.2", 1);
 
     /// mfiler3のホームディレクトリを保存しておく ///
     char* home = getenv("HOME");
@@ -940,7 +946,7 @@ int main(int argc, char* argv[])
             if(strcmp(argv[i], "--version") == 0) version();
 
             switch (argv[i][1]){
-/*
+#if defined(ENABLE_SOCKET)
                 case 'E':
                     if(i+2 < argc && atoi(argv[i+1]) != 0) {
                         pid = atoi(argv[i+1]);
@@ -972,7 +978,7 @@ int main(int argc, char* argv[])
                         usage();
                     }
                     break;
-*/
+#endif
 
                 case 'c':
                     if(i+1 < argc) {
@@ -990,6 +996,7 @@ int main(int argc, char* argv[])
         }
     }
 
+#if defined(ENABLE_SOCKET)
     /// オプションで指定されているなら動いている ///
     /// mfiler3にメッセージを送る  ///
     if(send_cmd[0] == 'E') {
@@ -1096,6 +1103,7 @@ int main(int argc, char* argv[])
 
         return 0;
     }
+#endif
 
     /// 標準入力と出力が制御端末かどうか確認 ///
     if(!isatty(0) || !isatty(1)) {
@@ -1283,6 +1291,7 @@ int main(int argc, char* argv[])
             }
         }
 
+#if defined(ENABLE_SOCKET)
         /// UNIX Domainソケット処理 ///
         else if(FD_ISSET(soc, &read_ok)) {
             char buf[BUFSIZ];
@@ -1291,6 +1300,7 @@ int main(int argc, char* argv[])
             socklen_t caddr_len;
             int len = recvfrom(soc, buf, BUFSIZ, 0, (struct sockaddr *)&caddr, &caddr_len);
 
+
             if(buf[0] == 'E') {
                 mclear();
                 mmove(0,0);
@@ -1339,6 +1349,7 @@ int main(int argc, char* argv[])
                 string_delete(str);
             }
         }
+#endif
 
         /// ジョブ処理 ///
         saphire_wait_background_job();
